@@ -1,6 +1,6 @@
 # The MIT License (MIT)
 #
-# Copyright (c) 2021 vn.py
+# Copyright (c) 2021-present, Xiaoyou Chen
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,11 +21,10 @@
 # SOFTWARE.
 
 
-import importlib_metadata
-
 from .taos_database import TaosDatabase as Database
 
-try:
-    __version__ = importlib_metadata.version("vnpy_taos")
-except importlib_metadata.PackageNotFoundError:
-    __version__ = "dev"
+
+__all__ = ["Database"]
+
+
+__version__ = "1.1.1"
